@@ -39,7 +39,7 @@ typedef struct CPU_Status
 void	CPU_Reset (void);
 void	CPU_GetStatus (CPU_Status *cpu_status);
 void	CPU_PutStatus (CPU_Status *cpu_status);
-int	GO (int CONTINUE);
+int	GO (void);
 
 #define	RAM		0
 #define	ROM		1
@@ -48,18 +48,16 @@ int	GO (int CONTINUE);
 extern UBYTE	memory[65536];
 extern UBYTE	attrib[65536];
 
-extern UBYTE (*XGetByte)  (UWORD addr);
-extern void  (*XPutByte)  (UWORD addr, UBYTE byte);
-extern void  (*Hardware) (void);
 extern void  (*Escape)   (UBYTE code);
 
-#define	GetByte(addr)		((attrib[addr] == HARDWARE) ? XGetByte(addr) : memory[addr])
-#define	PutByte(addr,byte)	if (attrib[addr] == RAM) memory[addr] = byte; else if (attrib[addr] == HARDWARE) XPutByte(addr,byte);
+#define	GetByte(addr)		((attrib[addr] == HARDWARE) ? Atari800_GetByte(addr) : memory[addr])
+#define	PutByte(addr,byte)	if (attrib[addr] == RAM) memory[addr] = byte; else if (attrib[addr] == HARDWARE) Atari800_PutByte(addr,byte);
 #define	GetWord(addr)		((GetByte(addr+1) << 8) | GetByte(addr))
 
 #define	NMI_MASK	0x01
 #define	IRQ_MASK	0x02
 
 extern int	INTERRUPT;
+extern int	ncycles;
 
 #endif
